# This file is generated by numpy's build process
# It contains system_info results at the time of building this package.
from enum import Enum
from numpy.core._multiarray_umath import (
    __cpu_features__,
    __cpu_baseline__,
    __cpu_dispatch__,
)

__all__ = ["show"]
_built_with_meson = True


class DisplayModes(Enum):
    stdout = "stdout"
    dicts = "dicts"


def _cleanup(d):
    """
    Removes empty values in a `dict` recursively
    This ensures we remove values that Meson could not provide to CONFIG
    """
    if isinstance(d, dict):
        return {k: _cleanup(v) for k, v in d.items() if v and _cleanup(v)}
    else:
        return d


CONFIG = _cleanup(
    {
        "Compilers": {
            "c": {
                "name": "clang",
                "linker": "ld64",
                "version": "14.0.6",
                "commands": "x86_64-apple-darwin13.4.0-clang",
            },
            "cython": {
                "name": "cython",
                "linker": "cython",
                "version": "3.0.0",
                "commands": "cython",
            },
            "c++": {
                "name": "clang",
                "linker": "ld64",
                "version": "14.0.6",
                "commands": "x86_64-apple-darwin13.4.0-clang++",
            },
        },
        "Machine Information": {
            "host": {
                "cpu": "x86_64",
                "family": "x86_64",
                "endian": "little",
                "system": "darwin",
            },
            "build": {
                "cpu": "x86_64",
                "family": "x86_64",
                "endian": "little",
                "system": "darwin",
            },
            "cross-compiled": bool("False".lower().replace("false", "")),
        },
        "Build Dependencies": {
            "blas": {
                "name": "mkl-sdl",
                "found": bool("True".lower().replace("false", "")),
                "version": "2023.1",
                "detection method": "pkgconfig",
                "include directory": r"/var/folders/c_/qfmhj66j0tn016nkx_th4hxm0000gp/T/abs_dfryapvjbb/croot/numpy_and_numpy_base_1701362404676/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_pla/include",
                "lib directory": r"/var/folders/c_/qfmhj66j0tn016nkx_th4hxm0000gp/T/abs_dfryapvjbb/croot/numpy_and_numpy_base_1701362404676/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_pla/lib",
                "openblas configuration": "unknown",
                "pc file directory": r"/var/folders/c_/qfmhj66j0tn016nkx_th4hxm0000gp/T/abs_dfryapvjbb/croot/numpy_and_numpy_base_1701362404676/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_pla/lib/pkgconfig",
            },
            "lapack": {
                "name": "dep4510964272",
                "found": bool("True".lower().replace("false", "")),
                "version": "1.26.2",
                "detection method": "internal",
                "include directory": r"unknown",
                "lib directory": r"unknown",
                "openblas configuration": "unknown",
                "pc file directory": r"unknown",
            },
        },
        "Python Information": {
            "path": r"/var/folders/c_/qfmhj66j0tn016nkx_th4hxm0000gp/T/abs_dfryapvjbb/croot/numpy_and_numpy_base_1701362404676/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_pla/bin/python",
            "version": "3.12",
        },
        "SIMD Extensions": {
            "baseline": __cpu_baseline__,
            "found": [
                feature for feature in __cpu_dispatch__ if __cpu_features__[feature]
            ],
            "not found": [
                feature for feature in __cpu_dispatch__ if not __cpu_features__[feature]
            ],
        },
    }
)


def _check_pyyaml():
    import yaml

    return yaml


def show(mode=DisplayModes.stdout.value):
    """
    Show libraries and system information on which NumPy was built
    and is being used

    Parameters
    ----------
    mode : {`'stdout'`, `'dicts'`}, optional.
        Indicates how to display the config information.
        `'stdout'` prints to console, `'dicts'` returns a dictionary
        of the configuration.

    Returns
    -------
    out : {`dict`, `None`}
        If mode is `'dicts'`, a dict is returned, else None

    See Also
    --------
    get_include : Returns the directory containing NumPy C
                  header files.

    Notes
    -----
    1. The `'stdout'` mode will give more readable
       output if ``pyyaml`` is installed

    """
    if mode == DisplayModes.stdout.value:
        try:  # Non-standard library, check import
            yaml = _check_pyyaml()

            print(yaml.dump(CONFIG))
        except ModuleNotFoundError:
            import warnings
            import json

            warnings.warn("Install `pyyaml` for better output", stacklevel=1)
            print(json.dumps(CONFIG, indent=2))
    elif mode == DisplayModes.dicts.value:
        return CONFIG
    else:
        raise AttributeError(
            f"Invalid `mode`, use one of: {', '.join([e.value for e in DisplayModes])}"
        )
